"use strict";
// Copyright (c) Rodrigo Speller. All rights reserved.
// Licensed under the Apache License, Version 2.0.
// See License.txt in the project root for license information.
Object.defineProperty(exports, "__esModule", { value: true });
const abstractions_1 = require("./abstractions");
const ResolvingTagStack_1 = require("./ResolvingTagStack");
const CircularDependencyError_1 = require("./Error/CircularDependencyError");
class ActivatorContainer {
    constructor(source, resolvingStack = new ResolvingTagStack_1.default()) {
        this.source = source;
        this.resolvingStack = resolvingStack;
    }
    activate(factory) {
        let typeFactory = factory[abstractions_1.resolver];
        if (typeFactory != null)
            factory = typeFactory;
        return factory(this);
    }
    createScope() {
        return this.source.createScope();
    }
    resolve(arg1) {
        let entry = this.source.getEntry(arg1);
        if (entry == null)
            return;
        let resolvingStack = this.resolvingStack;
        if (resolvingStack.contains(entry.tag))
            throw new CircularDependencyError_1.default();
        return entry.resolve(new ActivatorContainer(this.source, resolvingStack.append(entry.tag)));
    }
}
exports.default = ActivatorContainer;
